@@ -99,12 +99,12 @@ Rtree_init(Rtree *self, PyObject *args, PyObject *kwds)
 
     self->index = RtreeIndex_new(basename, nPageLength, load);
     
-    if (RtreeIndex_isValid(self->index) != 1) {
-        PyErr_Format(PyExc_IOError,
-            "Index layout is invalid"
-            );
-        return -1;
-	}
+//    if (RtreeIndex_isValid(self->index) != 1) {
+//        PyErr_Format(PyExc_IOError,
+//            "Index layout is invalid"
+//            );
+//        return -1;
+//	}
     return 0;
 }
 
@@ -114,11 +114,11 @@ static PyObject *
 Rtree_add(Rtree *self, PyObject *args)
 {
     double min[2], max[2];
-    long id;
+    long long id;
     int size;
     PyObject *bounds=NULL;
 
-    if (!PyArg_ParseTuple(args, "lO", &id, &bounds))
+    if (!PyArg_ParseTuple(args, "LO", &id, &bounds))
         return NULL;
 
     /* Check length of the bounds argument */
@@ -148,22 +148,35 @@ Rtree_add(Rtree *self, PyObject *args)
             size);
         return NULL;
     }
-  
-    RtreeIndex_insertData(self->index, id, min, max);
+ 
+    /* Check validity of bounds */
+    if (min[0] > max[0] || min[1] > max[1])
+    {
+        PyErr_SetString(PyExc_ValueError,
+            "Bounding box is invalid: maxx < miny or maxy < miny"
+            );
+        return NULL;
+    }
+
+    if (RtreeIndex_insertData(self->index, id, min, max) ) {
+        Py_INCREF(Py_None);
+        return Py_None;        
+    } else {
+        return NULL;
+    }
     
-    Py_INCREF(Py_None);
-    return Py_None;
+
 }
 
 static PyObject *
 Rtree_deleteData(Rtree *self, PyObject *args)
 {
     double min[2], max[2];
-    long id;
+    long long id;
     int size;
     PyObject *bounds=NULL;
 
-    if (!PyArg_ParseTuple(args, "lO", &id, &bounds))
+    if (!PyArg_ParseTuple(args, "LO", &id, &bounds))
         return NULL;
 
     /* Check length of the bounds argument */
@@ -193,11 +206,23 @@ Rtree_deleteData(Rtree *self, PyObject *args)
             size);
         return NULL;
     }
-  
-    RtreeIndex_deleteData(self->index, id, min, max);
+
+    /* Check validity of bounds */
+    if (min[0] > max[0] || min[1] > max[1])
+    {
+        PyErr_SetString(PyExc_ValueError,
+            "Bounding box is invalid: maxx < miny or maxy < miny"
+            );
+        return NULL;
+    }
     
-    Py_INCREF(Py_None);
-    return Py_None;
+    if (RtreeIndex_deleteData(self->index, id, min, max) ) {
+        Py_INCREF(Py_None);
+        return Py_None;        
+    } else {
+        return NULL;
+    }    
+
 }
 
 static PyObject *
@@ -207,7 +232,16 @@ Rtree_intersection(Rtree *self, PyObject *args)
 
     if (!PyArg_ParseTuple(args, "(dddd)", &min[0], &min[1], &max[0], &max[1]))
         return NULL;
-    
+
+    /* Check validity of bounds */
+    if (min[0] > max[0] || min[1] > max[1])
+    {
+        PyErr_SetString(PyExc_ValueError,
+            "Bounding box is invalid: maxx < miny or maxy < miny"
+            );
+        return NULL;
+    }
+
     return RtreeIndex_intersects(self->index, min, max);
 }
 
@@ -253,6 +287,15 @@ Rtree_nearsetNeighbors(Rtree *self, PyObject *args)
         return NULL;
     }
 
+    /* Check validity of bounds */
+    if (min[0] > max[0] || min[1] > max[1])
+    {
+        PyErr_SetString(PyExc_ValueError,
+            "Bounding box is invalid: maxx < miny or maxy < miny"
+            );
+        return NULL;
+    }
+
     return RtreeIndex_nearestNeighbors(self->index, num_results, min, max);
 }
 
